@@ -4,16 +4,16 @@ import datetime
 import socket
 from msmart.security import security
 
-VERSION = '0.1.21'
+VERSION = '0.1.22'
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class lan:
-    def __init__(self, device_ip, device_id):
+    def __init__(self, device_ip, device_id, device_port=6444):
         self.device_ip = device_ip
         self.device_id = device_id
-        self.device_port = 6444
+        self.device_port = device_port
         self.security = security()
         self._retries = 0
 
